@@ -31,11 +31,11 @@ import android.view.LayoutInflater;
 import android.view.View;
 import android.view.ViewGroup;
 import android.widget.ArrayAdapter;
-import android.widget.LinearLayout;
 
-import org.videolan.vlc.MediaWrapper;
+import org.videolan.vlc.media.MediaWrapper;
 import org.videolan.vlc.R;
 import org.videolan.vlc.databinding.AudioBrowserItemBinding;
+import org.videolan.vlc.gui.helpers.MediaComparators;
 import org.videolan.vlc.interfaces.IAudioClickHandler;
 
 import java.util.ArrayList;
@@ -69,7 +69,7 @@ public class AlbumAdapter extends ArrayAdapter<MediaWrapper> implements IAudioCl
         } else
             holder = (ViewHolder) v.getTag(R.layout.audio_browser_item);
 
-        holder.position = position;
+        holder.binding.setPosition(position);
         holder.binding.setMedia(mw);
         holder.binding.setFooter(position != mMediaList.size() - 1);
         holder.binding.setClickable(mContextPopupMenuListener != null);
@@ -105,12 +105,11 @@ public class AlbumAdapter extends ArrayAdapter<MediaWrapper> implements IAudioCl
     @Override
     public void onMoreClick(View v) {
         if (mContextPopupMenuListener != null)
-                mContextPopupMenuListener.onPopupMenu(v, ((ViewHolder) ((LinearLayout)v.getParent().getParent()).getTag(R.layout.audio_browser_item)).position);
+                mContextPopupMenuListener.onPopupMenu(v, ((Integer)v.getTag()).intValue());
     }
 
     static class ViewHolder {
         AudioBrowserItemBinding binding;
-        int position;
     }
 
     public interface ContextPopupMenuListener {
