@@ -43,10 +43,12 @@ import android.widget.ImageView;
 import android.widget.ListView;
 
 import org.videolan.libvlc.util.AndroidUtil;
-import org.videolan.vlc.MediaWrapper;
 import org.videolan.vlc.R;
 import org.videolan.vlc.gui.PlaybackServiceFragment;
+import org.videolan.vlc.gui.helpers.AudioUtil;
+import org.videolan.vlc.media.MediaWrapper;
 import org.videolan.vlc.util.AndroidDevices;
+import org.videolan.vlc.util.FileUtils;
 
 import java.util.ArrayList;
 
@@ -168,6 +170,9 @@ public class AudioAlbumFragment extends PlaybackServiceFragment implements Adapt
         menu.setGroupVisible(R.id.songs_view_only, false);
         menu.findItem(R.id.audio_list_browser_delete).setVisible(false);
         menu.setGroupVisible(R.id.phone_only, AndroidDevices.isPhone());
+        //Hide delete if we cannot
+        String location = mMediaList.get(position).getLocation();
+        menu.findItem(R.id.audio_list_browser_delete).setVisible(FileUtils.canWrite(location));
     }
 
     @Override
