@@ -203,7 +203,7 @@ public class VideoListAdapter extends RecyclerView.Adapter<VideoListAdapter.View
 
     @Nullable
     public MediaWrapper getItem(int position) {
-        if (position < 0 || position > mVideos.size())
+        if (position < 0 || position >= mVideos.size())
             return null;
         else
             return mVideos.get(position);
@@ -219,7 +219,9 @@ public class VideoListAdapter extends RecyclerView.Adapter<VideoListAdapter.View
         if (position == -1)
             return;
         mVideos.remove(position);
-        notifyItemRemoved(position);
+        // Remove the whole end of list to update position tags stored in
+        // items views for databinder interactions, like contextual menu
+        notifyItemRangeChanged(position, getItemCount()-position);
     }
 
     private int getItemPosition(MediaWrapper mw) {
